@@ -1,6 +1,6 @@
 package Fey::Test;
 BEGIN {
-  $Fey::Test::VERSION = '0.08';
+  $Fey::Test::VERSION = '0.09';
 }
 
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use DBI;
 use File::Temp ();
 
-use Fey 0.10;
+use Fey;
 use Fey::Column;
 use Fey::FK;
 use Fey::Schema;
@@ -394,9 +394,6 @@ sub _mock_foreign_key_info {
 
 package    # hide from PAUSE
     Fey::Test::MockSTH;
-BEGIN {
-  $Fey::Test::MockSTH::VERSION = '0.08';
-}
 
 sub new {
     my $class = shift;
@@ -427,7 +424,7 @@ Fey::Test - Test libraries for Fey distros
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -455,7 +452,7 @@ This software is Copyright (c) 2010 by Dave Rolsky.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
