@@ -1,6 +1,6 @@
 package Fey::Test::Pg;
 BEGIN {
-  $Fey::Test::Pg::VERSION = '0.08';
+  $Fey::Test::Pg::VERSION = '0.09';
 }
 
 use strict;
@@ -14,10 +14,10 @@ BEGIN {
         plan skip_all => 'These tests require DBD::Pg';
     }
 
-    unless ( $ENV{FEY_MAINTAINER_TEST_PG} || -d '.hg' ) {
+    unless ( $ENV{RELEASE_TESTING} || $ENV{AUTHOR_TESTING} || -d '.hg' ) {
         plan skip_all =>
-            'These tests are only run if the FEY_MAINTAINER_TEST_PG'
-            . ' env var is true, or if being run from an SVN checkout dir.';
+            'These tests are only run if either the RELEASE_TESTING or AUTHOR_TESTING'
+            . ' env var is true, or if being run from a Mercurial checkout dir.';
     }
 }
 
@@ -117,7 +117,7 @@ Fey::Test::Pg
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 AUTHOR
 
@@ -129,7 +129,7 @@ This software is Copyright (c) 2010 by Dave Rolsky.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
